@@ -8,8 +8,8 @@ By Dan Porter, PhD
 Diamond
 2017
 
-Version 1.9.3
-Last updated: 15/02/21
+Version 1.9.5
+Last updated: 15/11/21
 
 Version History:
 18/08/17 0.1    Program created
@@ -29,6 +29,8 @@ Version History:
 26/11/20 1.9.1  Added layers input to plot_layers
 21/01/21 1.9.2  Added plot_xray_resonance
 15/02/21 1.9.3  Added axis_reciprocal_lattice_points/lines/vectors
+11/10/21 1.9.4  Centered crystal in plot_crystal
+15/11/21 1.9.5  Added plot_diffractometer_reciprocal_space
 
 @author: DGPorter
 """
@@ -42,7 +44,7 @@ from . import functions_general as fg
 from . import functions_plotting as fp
 from . import functions_crystallography as fc
 
-__version__ = '1.9.3'
+__version__ = '1.9.5'
 
 
 class Plotting:
@@ -80,6 +82,8 @@ class Plotting:
         
         # Get atomic positions
         R = self.xtl.Cell.calculateR(uvw)
+        cen = np.mean(R, axis=0)
+        R = R - cen
         #I = np.all(np.logical_and(uvw<1+tol, uvw>0-tol, occ>0.2),1)
         I = np.all(np.hstack([uvw<(1+tol),uvw>(0-tol),occ.reshape([-1,1])>0.2]),1)
         
@@ -95,26 +99,26 @@ class Plotting:
             # don't plot unoccupied positions
             tot_occ = np.array([occ[m] for m in range(len(R)) if invidx[m] == n])
             if sum(tot_occ) == 0: continue
-            
-            xyz = np.array([R[m,:] for m in range(len(R)) if invidx[m] == n])
+
+            xyz = np.array([R[m, :] for m in range(len(R)) if invidx[m] == n])
             iii = np.array([I[m] for m in range(len(R)) if invidx[m] == n])
-            col = np.tile(colors[n], (len(xyz[iii,:]),1) )
-            ax.scatter(xyz[iii,0], xyz[iii,1], xyz[iii,2], s=2*sizes[n], c=col, label=labels[n], cmap=colors)
+            col = np.tile(colors[n], (len(xyz[iii, :]), 1))
+            ax.scatter(xyz[iii, 0], xyz[iii, 1], xyz[iii, 2], s=2 * sizes[n], c=col, label=labels[n], cmap=colors)
             
             #mxyz = np.array([mxmymz[m,:] for m in range(len(R)) if invidx[m] == n])
             
             for m in range(len(R)): 
                 if invidx[m] == n and I[m]:
-                    xyz = R[m,:]
-                    vec = V[m,:]
+                    xyz = R[m, :]
+                    vec = V[m, :]
                     if fg.mag(vec) < 0.1: continue
-                    vx,vy,vz = np.asarray([xyz - vec/2, xyz + vec/2]).T
-                    fp.plot_arrow(vx,vy,vz,col='r',arrow_size=20,width=3)
+                    vx, vy, vz = np.asarray([xyz - vec / 2, xyz + vec / 2]).T
+                    fp.plot_arrow(vx, vy, vz, col='r', arrow_size=20, width=3)
         
         # Labels
         if show_labels:
             uvw_st, type_st, label_st, occ_st, uiso_st, mxmymz_st = self.xtl.Structure.get()
-            R_st = self.xtl.Cell.calculateR(uvw_st)
+            R_st = self.xtl.Cell.calculateR(uvw_st) - cen
             for n in range(len(R_st)):
                 ax.text(R_st[n, 0], R_st[n, 1], R_st[n, 2], '%2d: %s' % (n, label_st[n]), fontsize=10)
         
@@ -122,15 +126,15 @@ class Plotting:
         uvw = np.array([[0., 0, 0], [1, 0, 0], [1, 0, 1], [1, 1, 1], [1, 1, 0], [0, 1, 0], [0, 1, 1],
                         [0, 0, 1], [1, 0, 1], [1, 0, 0], [1, 1, 0], [1, 1, 1], [0, 1, 1], [0, 1, 0], [0, 0, 0],
                         [0, 0, 1]])
-        bpos = np.dot(uvw, self.xtl.Cell.UV())
+        bpos = self.xtl.Cell.calculateR(uvw) - cen
         ax.plot(bpos[:, 0], bpos[:, 1], bpos[:, 2], c='k')  # cell box
         fp.plot_arrow(bpos[[0, 1], 0], bpos[[0, 1], 1], bpos[[0, 1], 2], col='r', width=4)  # a
         fp.plot_arrow(bpos[[0, 5], 0], bpos[[0, 5], 1], bpos[[0, 5], 2], col='g', width=4)  # b
         fp.plot_arrow(bpos[[0, 7], 0], bpos[[0, 7], 1], bpos[[0, 7], 2], col='b', width=4)  # c
         lim = np.max(self.xtl.Cell.lp()[:3])
-        ax.set_xlim(-lim / 10, lim)
-        ax.set_ylim(-lim / 10, lim)
-        ax.set_zlim(-lim / 10, lim)
+        ax.set_xlim(-lim/2, lim/2)
+        ax.set_ylim(-lim/2, lim/2)
+        ax.set_zlim(-lim/2, lim/2)
         # ax.axis('equal')
         ax.set_axis_off()
         
@@ -303,7 +307,7 @@ class Plotting:
             I = I/(Qmag+0.001)**2
         
         # create plotting mesh
-        pixels = int(2000*q_max)  # reduce this to make convolution faster
+        pixels = int(self.xtl.Scatter._powder_pixels * q_max)  # reduce this to make convolution faster
         pixel_size = q_max/(1.0*pixels)
         peak_width_pixels = peak_width/(1.0*pixel_size)
         mesh = np.zeros([pixels])
@@ -327,15 +331,16 @@ class Plotting:
         
         # add reflections to background
         # scipy.interpolate.griddata?
-        mesh_x = np.linspace(0, max_x, pixels)
-        pixel_coord = xx/ max_x
-        pixel_coord = (pixel_coord*(pixels-1)).astype(int)
+        mesh_x = np.linspace(min_x, max_x, pixels)
+        #pixel_coord = xx/ max_x
+        pixel_coord = (xx - min_x) / (max_x - min_x)
+        pixel_coord = (pixel_coord * pixels).astype(int)
 
-        ref_n = [0]
-        ref_txt = ['']
+        ref_n = []
+        ref_txt = []
         ext_n = []
         ext_txt = []
-        for n in range(1, len(I)):
+        for n in range(len(I)):
             if xx[n] > max_x or xx[n] < min_x:
                 continue
             mesh[pixel_coord[n]] = mesh[pixel_coord[n]] + I[n]
@@ -347,15 +352,15 @@ class Plotting:
                 # generate label if not too close to another reflection
                 if I[n] > 0.1:
                     ref_n += [pixel_coord[n]]
-                    ref_txt += ['(%1.0f,%1.0f,%1.0f)' % (HKL[n,0],HKL[n,1],HKL[n,2])]
+                    ref_txt += ['(%1.0f,%1.0f,%1.0f)' % (HKL[n, 0], HKL[n, 1], HKL[n, 2])]
                 else:
                     ext_n += [pixel_coord[n]]
-                    ext_txt += ['(%1.0f,%1.0f,%1.0f)' % (HKL[n,0],HKL[n,1],HKL[n,2])]
+                    ext_txt += ['(%1.0f,%1.0f,%1.0f)' % (HKL[n, 0], HKL[n, 1], HKL[n, 2])]
         
         # Convolve with a gaussian (if >0 or not None)
         if peak_width:
             gauss_x = np.arange(-3*peak_width_pixels,3*peak_width_pixels+1) # gaussian width = 2*FWHM
-            G = fg.gauss(gauss_x, None, height=1, cen=0, fwhm=peak_width_pixels, bkg=0)
+            G = fg.gauss(gauss_x, None, height=1, centre=0, fwhm=peak_width_pixels, bkg=0)
             mesh = np.convolve(mesh,G, mode='same') 
         
         # Add background (if >0 or not None)
@@ -585,22 +590,22 @@ class Plotting:
              hhl plot:
             xtl.simulate_intensity_cut([1,1,0],[0,0,1],[0,0,0])
         """
-        
+
         # Determine the directions in cartesian space
         x_cart = fg.norm(self.xtl.Cell.calculateQ(x_axis))
         y_cart = fg.norm(self.xtl.Cell.calculateQ(y_axis))
-        z_cart = fg.norm(np.cross( x_cart, y_cart )) # z is perp. to x+y
-        y_cart = np.cross(x_cart,z_cart) # make sure y is perp. to x
+        z_cart = fg.norm(np.cross(x_cart, y_cart))  # z is perp. to x+y
+        y_cart = np.cross(x_cart, z_cart)  # make sure y is perp. to x
         c_cart = self.xtl.Cell.calculateQ(centre)
-        
+
         # Correct y-axis for label - original may not have been perp. to x_axis (e.g. hexagonal)
         y_axis = fg.norm(self.xtl.Cell.indexQ(y_cart))
-        y_axis = -y_axis/np.min(np.abs(y_axis[np.abs(y_axis)>0])) + 0.0 # +0.0 to remove -0
+        y_axis = -y_axis / np.min(np.abs(y_axis[np.abs(y_axis) > 0])) + 0.0  # +0.0 to remove -0
         
         # Determine orthogonal lattice vectors for plotting lines and labels
         vec_a = x_axis
-        vec_c = np.cross(x_axis,y_axis)
-        vec_b = fg.norm(np.cross(vec_c,vec_a))
+        vec_c = np.cross(x_axis, y_axis)
+        vec_b = fg.norm(np.cross(vec_c, vec_a))
         
         # Generate intensity cut
         X, Y, mesh = self.generate_intensity_cut(x_axis, y_axis, centre, q_max, cut_width, background, peak_width)
@@ -608,24 +613,24 @@ class Plotting:
         # create figure
         plt.figure(figsize=self._figure_size, dpi=self._figure_dpi)
         cmap = plt.get_cmap('hot_r')
-        plt.pcolormesh(X,Y,mesh,cmap=cmap)
+        plt.pcolormesh(X, Y, mesh, cmap=cmap)
         plt.axis('image')
         plt.colorbar()
         plt.clim([background-(np.max(mesh)/200),background+(np.max(mesh)/50)])
-        
+
         # Lattice points and vectors within the plot
         Q_vec_a = self.xtl.Cell.calculateQ(vec_a)
         Q_vec_b = self.xtl.Cell.calculateQ(vec_b)
-        
-        CELL = np.array([2*q_max*x_cart,-2*q_max*y_cart,cut_width*z_cart]) # Plot/mesh unit cell
-        
-        mesh_vec_a = fg.index_coordinates(Q_vec_a, CELL)*2*q_max # coordinates wrt plot axes
-        mesh_vec_b = fg.index_coordinates(Q_vec_b, CELL)*2*q_max
-        
+
+        CELL = np.array([2 * q_max * x_cart, -2 * q_max * y_cart, cut_width * z_cart])  # Plot/mesh unit cell
+
+        mesh_vec_a = fg.index_coordinates(Q_vec_a, CELL) * 2 * q_max  # coordinates wrt plot axes
+        mesh_vec_b = fg.index_coordinates(Q_vec_b, CELL) * 2 * q_max
+
         # Vector arrows and lattice point labels
-        cen_lab = '(%1.3g,%1.3g,%1.3g)' % (centre[0],centre[1],centre[2])
-        vec_a_lab = '(%1.3g,%1.3g,%1.3g)' % (vec_a[0]+centre[0],vec_a[1]+centre[1],vec_a[2]+centre[2])
-        vec_b_lab = '(%1.3g,%1.3g,%1.3g)' % (vec_b[0]+centre[0],vec_b[1]+centre[1],vec_b[2]+centre[2])
+        cen_lab = '(%1.3g,%1.3g,%1.3g)' % (centre[0], centre[1], centre[2])
+        vec_a_lab = '(%1.3g,%1.3g,%1.3g)' % (vec_a[0] + centre[0], vec_a[1] + centre[1], vec_a[2] + centre[2])
+        vec_b_lab = '(%1.3g,%1.3g,%1.3g)' % (vec_b[0] + centre[0], vec_b[1] + centre[1], vec_b[2] + centre[2])
 
         lattQ = fp.axis_lattice_points(mesh_vec_a, mesh_vec_b, plt.axis())
         fp.plot_lattice_lines(lattQ, mesh_vec_a, mesh_vec_b)
@@ -697,7 +702,46 @@ class Plotting:
         
         ttl = '%s\nE = %1.3f keV' % (self.xtl.name,energy_kev)
         fp.labels(ttl)
-    
+
+    def plot_diffractometer_reciprocal_space(self, energy_kev, delta=0, gamma=0):
+        """
+        Plot diffractometer angles using orientation
+        :param energy_kev:
+        :param delta:
+        :param gamma:
+        :return: None
+        """
+        uv = self.xtl.Cell.UV()
+        uvstar = fc.RcSp(uv)
+        maxhkl = fc.maxHKL(2, uvstar)
+        hkl = fc.genHKL(*maxhkl)
+        qdet, ki, kf = self.xtl.Cell.diff6circle(delta, gamma, energy_kev=energy_kev)
+        qlab = self.xtl.Cell.calculateQ(hkl)
+        astar = self.xtl.Cell.calculateQ([1, 0, 0])[0]
+        bstar = self.xtl.Cell.calculateQ([0, 1, 0])[0]
+        cstar = self.xtl.Cell.calculateQ([0, 0, 1])[0]
+
+        fig = plt.figure(figsize=fp.FIGURE_SIZE, dpi=fp.FIGURE_DPI)
+        ax = fig.add_subplot(111, projection='3d')
+
+        def pltvec(vec, *args, **kwargs):
+            vec = np.reshape(vec, (-1, 3))
+            return plt.plot(vec[:, 1], vec[:, 2], vec[:, 0], *args, **kwargs)
+
+        pltvec(qlab, 'r+', ms=12, label='hkl')
+        pltvec([-ki, [0, 0, 0], kf, [0, 0, 0], qdet], 'k-', lw=5, label='q = kf - ki')
+        pltvec([[0, 0, 0], qdet], 'm-', lw=5, label='q = kf - ki')
+        pltvec([[0, 0, 0], astar], 'b-', lw=5, label='astar')
+        pltvec([[0, 0, 0], bstar], 'g-', lw=5, label='bstar')
+        pltvec([[0, 0, 0], cstar], 'y-', lw=5, label='cstar')
+        fp.labels(None, 'Y', 'Z', 'X', legend=True)
+        ax.set_xlim([2, -2])
+        ax.set_ylim([2, -2])
+        ax.set_zlim([-2, 2])
+        # ax.invert_xaxis()
+        # ax.invert_yaxis()
+        plt.show()
+
     def plot_3Dlattice(self,q_max=4.0,x_axis=[1,0,0],y_axis=[0,1,0],centre=[0,0,0],cut_width=0.05):
         """
         Plot lattice points in 3D
@@ -1510,7 +1554,7 @@ class MultiPlotting:
             # Convolve with a gaussian
             if peak_width:
                 gauss_x = np.arange(-3*peak_width_pixels,3*peak_width_pixels+1) # gaussian width = 2*FWHM
-                G = fg.gauss(gauss_x, None, height=1, cen=0, fwhm=peak_width_pixels, bkg=0)
+                G = fg.gauss(gauss_x, None, height=1, centre=0, fwhm=peak_width_pixels, bkg=0)
                 mesh = np.convolve(mesh, G, mode='same')
             
             # Add background
